This is a demonstration package for **docassemble**.

See the [docassemble web site](https://docassemble.org) for
a description of **docassemble** and installation instructions.

To get help with using **docassemble**, join the 
[docassemble mailing list](https://mail.python.org/mm3/mailman3/lists/docassemble.python.org/)
and/or the [docassemble Slack group](https://join.slack.com/t/docassemble/shared_invite/enQtMjQ0Njc1NDk0NjU2LTAzYzY5NWExMzUxNTNhNjUyZjRkMDg0NGE2Yjc2YjI0OGNlMTcwNjhjYzRhMjljZWU0MTI2N2U0MTFlM2ZjNzg).
